class pe_razor::database(
  $dbpassword,
) {
  include puppet_enterprise::params

  # Without this, the default owner is 'pe-razor', which gets created
  # by the package (which hasn't happened yet).
  File {
    ensure => file,
    owner  => 'pe-postgres',
    group  => 'pe-postgres',
  }

  # We would like to run silent with regards to the deprecation warning around
  # the package type's allow_virtual parameter, and so must explicitly set a
  # default for it as long as we support clients older than 3.6.1. No packages
  # are declared here, but the postgresql class has package types. We will take
  # advantage of another feature that will be deprecated at some point (dynamic
  # scope for resource defaults) to accomplish the desired suppression of the
  # deprecation warning without modifying the postgresql module itself, by
  # setting the package resource defaults here.
  Package {
    allow_virtual => $puppet_enterprise::params::allow_virtual_default,
  }

  $pgsqldir = '/opt/puppet/var/lib/pgsql'
  $version = $puppet_enterprise::params::postgres_version
  # set our parameters for the params for to inherit
  class { '::pe_postgresql::globals':
    user                => 'pe-postgres',
    group               => 'pe-postgres',
    client_package_name => 'pe-postgresql',
    server_package_name => 'pe-postgresql-server',
    service_name        => 'pe-postgresql',
    default_database    => 'pe-postgres',
    version             => $version,
    bindir              => '/opt/puppet/bin',
    datadir             => "${pgsqldir}/${version}/data",
    confdir             => "${pgsqldir}/${version}/data",
    psql_path           => '/opt/puppet/bin/psql',
    needs_initdb        => true,
  }

  # manage the directories the pgsql server will use
  file {[$pgsqldir, "${pgsqldir}/${version}" ]:
    ensure  => directory,
    mode    => '0755',
    owner   => 'pe-postgres',
    group   => 'pe-postgres',
    require => Class['pe_postgresql::server::install'],
    before  => Class['pe_postgresql::server::initdb'],
  } ->

  # Ensure /etc/sysconfig/pgsql exists so the module can create and manage
  # pgsql/postgresql
  file { '/etc/sysconfig/pgsql':
    ensure => directory,
  }

  # get the pg server up and running
  class { '::pe_postgresql::server':
    listen_addresses        => $puppet_enterprise::params::database_listen_addresses,
    ip_mask_allow_all_users => '0.0.0.0/0',
  }

  # create the razor tablespace
  # create the razor database
  pe_postgresql::server::tablespace { 'razor':
    location => "${pgsqldir}/${version}/razor",
    require  => Class['::pe_postgresql::server'],
  }
  # create our database
  pe_postgresql::server::db { 'razor':
    user       => 'razor',
    password   => $dbpassword,
    tablespace => 'razor',
    require    => Pe_postgresql::Server::Tablespace['razor'],
  }

}
